@@ -19,6 +19,7 @@
 #' @template param_learner_properties
 #' @template param_data_formats
 #' @template param_packages
+#' @template param_label
 #' @template param_man
 #'
 #' @family Learner
@@ -36,13 +37,13 @@ LearnerSurv = R6Class("LearnerSurv",
   inherit = Learner,
   public = list(
     #' @description Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(id, param_set = ParamSet$new(), predict_types = "distr",
+    initialize = function(id, param_set = ps(), predict_types = "distr",
       feature_types = character(), properties = character(),
-      packages = character(), man = NA_character_) {
+      packages = character(), label = NA_character_, man = NA_character_) {
       super$initialize(
         id = id, task_type = "surv", param_set = param_set, predict_types = predict_types,
         feature_types = feature_types, properties = properties,
-        packages = c("mlr3proba", packages), man = man)
+        packages = c("mlr3proba", packages), label = label, man = man)
     }
   )
 )
