@@ -19,6 +19,7 @@
 #' @template param_predict_sets
 #' @template param_task_properties
 #' @template param_packages
+#' @template param_label
 #' @template param_man
 #' @template param_se
 #'
@@ -33,7 +34,7 @@ MeasureSurv = R6Class("MeasureSurv",
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function(id, param_set = ps(), range, minimize = NA, aggregator = NULL,
       properties = character(), predict_type = "distr", task_properties = character(),
-      packages = character(), man = NA_character_, se = FALSE) {
+      packages = character(), label = NA_character_, man = NA_character_, se = FALSE) {
       super$initialize(id,
         task_type = "surv", param_set = param_set, range = range, minimize = minimize,
         aggregator = aggregator, properties = properties, predict_type = predict_type,
