@@ -75,97 +75,102 @@
 #'   pod$predict(list(base = base, pred = pred))[[1]]
 #' }
 #' }
-PipeOpDistrCompositor = R6Class("PipeOpDistrCompositor",
-  inherit = mlr3pipelines::PipeOp,
-  public = list(
-    #' @description
-    #' Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(id = "compose_distr", param_vals = list(form = "aft", overwrite = FALSE)) {
-      super$initialize(
-        id = id,
-        param_set = ParamSet$new(params = list(
-          ParamFct$new("form", default = "aft", levels = c("aft", "ph", "po"), tags = c("predict")),
-          ParamLgl$new("overwrite", default = FALSE, tags = c("predict"))
-        )),
-        param_vals = param_vals,
-        input = data.table(name = c("base", "pred"), train = "NULL", predict = "PredictionSurv"),
-        output = data.table(name = "output", train = "NULL", predict = "PredictionSurv"),
-        packages = c("mlr3proba", "distr6")
-      )
-    }
-  ),
+delayedAssign(
+  "PipeOpDistrCompositor",
+  R6Class("PipeOpDistrCompositor",
+    inherit = mlr3pipelines::PipeOp,
+    public = list(
+      #' @description
+      #' Creates a new instance of this [R6][R6::R6Class] class.
+      initialize = function(id = "compose_distr", param_vals = list(form = "aft", overwrite = FALSE)) {
+        super$initialize(
+          id = id,
+          param_set = ps(
+            form = p_fct(default = "aft", levels = c("aft", "ph", "po"), tags = c("predict")),
+            overwrite = p_lgl(default = FALSE, tags = c("predict"))
+          ),
+          param_vals = param_vals,
+          input = data.table(name = c("base", "pred"), train = "NULL", predict = "PredictionSurv"),
+          output = data.table(name = "output", train = "NULL", predict = "PredictionSurv"),
+          packages = c("mlr3proba", "distr6")
+        )
+      }
+    ),
 
-  private = list(
-    .train = function(inputs) {
-      self$state = list()
-      list(NULL)
-    },
+    private = list(
+      .train = function(inputs) {
+        self$state = list()
+        list(NULL)
+      },
 
-    .predict = function(inputs) {
-      base = inputs$base
-      inpred = inputs$pred
+      .predict = function(inputs) {
+        base = inputs$base
+        inpred = inputs$pred
 
-      overwrite = self$param_set$values$overwrite
-      if (!length(overwrite)) overwrite = FALSE
+        overwrite = self$param_set$values$overwrite
+        if (!length(overwrite)) overwrite = FALSE
 
-      if ("distr" %in% inpred$predict_types & !overwrite) {
-        return(list(inpred))
-      } else {
-        assert("distr" %in% base$predict_types)
-
-        row_ids = inpred$row_ids
-        truth = inpred$truth
-
-        mlr3misc::map(inputs, function(x) checkmate::assert_true(identical(truth, x$truth)))
-
-        form = self$param_set$values$form
-        if (length(form) == 0) form = "aft"
-        nr = length(inpred$data$row_ids)
-
-        # assumes PH-style lp where high value = high risk
-        if (anyMissing(inpred$lp)) {
-          lp = inpred$crank
+        if ("distr" %in% inpred$predict_types & !overwrite) {
+          return(list(inpred))
         } else {
-          lp = inpred$lp
-        }
+          assert("distr" %in% base$predict_types)
 
-        if (inherits(base$data$distr, "Distribution")) {
-          base = distr6::as.MixtureDistribution(base$distr)
-          times = unlist(base[1]$properties$support$elements)
-          nc = length(times)
-          survmat = matrix(1 - base$cdf(times), nrow = nr, ncol = nc, byrow = TRUE)
-        } else {
-          base = colMeans(base$data$distr)
-          times = as.numeric(names(base))
-          nc = length(times)
-          survmat = matrix(base, nrow = nr, ncol = nc, byrow = TRUE)
-        }
+          row_ids = inpred$row_ids
+          truth = inpred$truth
 
-        timesmat = matrix(times, nrow = nr, ncol = nc, byrow = TRUE)
-        lpmat = matrix(lp, nrow = nr, ncol = nc)
+          mlr3misc::map(inputs, function(x) checkmate::assert_true(identical(truth, x$truth)))
+
+          form = self$param_set$values$form
+          if (length(form) == 0) form = "aft"
+          nr = length(inpred$data$row_ids)
+
+          # assumes PH-style lp where high value = high risk
+          if (anyMissing(inpred$lp)) {
+            lp = inpred$crank
+          } else {
+            lp = inpred$lp
+          }
+
+          if (inherits(base$data$distr, "Distribution")) {
+            base = distr6::as.MixtureDistribution(base$distr)
+            times = unlist(base[1]$properties$support$elements)
+            nc = length(times)
+            survmat = matrix(1 - base$cdf(times), nrow = nr, ncol = nc, byrow = TRUE)
+          } else {
+            base = colMeans(base$data$distr)
+            times = as.numeric(names(base))
+            nc = length(times)
+            survmat = matrix(base, nrow = nr, ncol = nc, byrow = TRUE)
+          }
+
+          timesmat = matrix(times, nrow = nr, ncol = nc, byrow = TRUE)
+          lpmat = matrix(lp, nrow = nr, ncol = nc)
 
         if (form == "ph") {
           cdf = 1 - (survmat^exp(lpmat))
         } else if (form == "aft") {
-          cdf = 1 - matrix(survmat[1, findInterval(timesmat / exp(lpmat), times)],
-                           nr, nc, FALSE)
+          mtc = findInterval(timesmat / exp(lpmat), times)
+          mtc[mtc == 0] = NA
+          cdf = 1 - matrix(survmat[1, mtc], nr, nc, FALSE)
+          cdf[is.na(cdf)] = 0
         } else if (form == "po") {
           cdf = 1 - (survmat * ((exp(-lpmat) + ((1 - exp(-lpmat)) * survmat))^-1))
           cdf[survmat == 1] = 0
         }
 
-        distr = .surv_return(times, 1 - cdf)$distr
+          distr = .surv_return(times, 1 - cdf)$distr
 
-        if (anyMissing(inpred$lp)) {
-          lp = NULL
-        } else {
-          lp = inpred$lp
+          if (anyMissing(inpred$lp)) {
+            lp = NULL
+          } else {
+            lp = inpred$lp
+          }
+
+          return(list(PredictionSurv$new(
+            row_ids = row_ids, truth = truth,
+            crank = inpred$crank, distr = distr, lp = lp)))
         }
-
-        return(list(PredictionSurv$new(
-          row_ids = row_ids, truth = truth,
-          crank = inpred$crank, distr = distr, lp = lp)))
       }
-    }
+    )
   )
 )
