@@ -61,69 +61,71 @@
 #'   poc$predict(list(pred_response, pred_se))[[1]]
 #' }
 #' }
-PipeOpProbregrCompositor = R6Class("PipeOpProbregrCompositor",
-  inherit = mlr3pipelines::PipeOp,
-  public = list(
-    #' @description
-    #' Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(id = "compose_probregr", param_vals = list(dist = "Normal")) {
-      ps = ParamSet$new(params = list(
-        ParamFct$new("dist", default = "Normal",
-          levels = distr6::listDistributions(filter = list(Tags = "locscale"),
-            simplify = TRUE),
-          tags = "predict")
-      ))
+delayedAssign(
+  "PipeOpProbregrCompositor",
+  R6Class("PipeOpProbregrCompositor",
+    inherit = mlr3pipelines::PipeOp,
+    public = list(
+      #' @description
+      #' Creates a new instance of this [R6][R6::R6Class] class.
+      initialize = function(id = "compose_probregr", param_vals = list(dist = "Normal")) {
+        ps = ps(
+          dist = p_fct(default = "Normal",
+            levels = distr6::listDistributions(filter = list(Tags = "locscale"), simplify = TRUE),
+            tags = "predict")
+        )
 
-      super$initialize(
-        id = id,
-        param_set = ps,
-        param_vals = param_vals,
-        input = data.table(name = c("input_response", "input_se"), train = "NULL",
-          predict = c("PredictionRegr", "PredictionRegr")),
-        output = data.table(name = "output", train = "NULL", predict = "PredictionRegr"),
-        packages = c("mlr3proba", "distr6")
-      )
-    }
-  ),
-
-  private = list(
-    .train = function(inputs) {
-      self$state = list()
-      list(NULL)
-    },
-
-    .predict = function(inputs) {
-      pred_response = inputs$input_response
-      pred_se = inputs$input_se
-
-      if ("se" %nin% pred_se$predict_types) {
-        stopf("'se' is not a predict_type in %s.", pred_se$id)
+        super$initialize(
+          id = id,
+          param_set = ps,
+          param_vals = param_vals,
+          input = data.table(name = c("input_response", "input_se"), train = "NULL",
+            predict = c("PredictionRegr", "PredictionRegr")),
+          output = data.table(name = "output", train = "NULL", predict = "PredictionRegr"),
+          packages = c("mlr3proba", "distr6")
+        )
       }
+    ),
 
-      response = pred_response$response
-      se = pred_se$se
+    private = list(
+      .train = function(inputs) {
+        self$state = list()
+        list(NULL)
+      },
 
-      assert(all(pred_response$truth == pred_se$truth))
-      assert(all(pred_response$row_ids == pred_se$row_ids))
+      .predict = function(inputs) {
+        pred_response = inputs$input_response
+        pred_se = inputs$input_se
 
-      pv = self$param_set$values
-      dist = pv$dist
+        if ("se" %nin% pred_se$predict_types) {
+          stopf("'se' is not a predict_type in %s.", pred_se$id)
+        }
 
-      if (is.null(dist) || dist %in% c("Normal")) {
-        params = data.table(mean = response, sd = se)
-      } else if (dist %in% c("Cauchy", "Gumbel")) {
-        params = data.table(location = response, scale = se)
-      } else if (dist %in% c("Laplace", "Logistic")) {
-        params = data.table(mean = response, scale = se)
+        response = pred_response$response
+        se = pred_se$se
+
+        assert(all(pred_response$truth == pred_se$truth))
+        assert(all(pred_response$row_ids == pred_se$row_ids))
+
+        pv = self$param_set$values
+        dist = pv$dist
+
+        if (is.null(dist) || dist %in% c("Normal")) {
+          params = data.table(mean = response, sd = se)
+        } else if (dist %in% c("Cauchy", "Gumbel")) {
+          params = data.table(location = response, scale = se)
+        } else if (dist %in% c("Laplace", "Logistic")) {
+          params = data.table(mean = response, scale = se)
+        }
+
+
+        list(PredictionRegr$new(row_ids = pred_response$row_ids,
+          truth = pred_response$truth,
+          response = response,
+          se = se,
+          distr = distr6::VectorDistribution$new(distribution = dist,
+            params = params)))
       }
-
-
-      list(PredictionRegr$new(row_ids = pred_response$row_ids,
-        truth = pred_response$truth,
-        response = response,
-        se = se,
-        distr = distr6::VectorDistribution$new(distribution = dist,
-          params = params)))
-    }
+    )
   )
 )
