@@ -29,7 +29,7 @@ PipeOpTaskTransformer = R6Class("PipeOpTaskTransformer",
   public = list(
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(id, param_set = ParamSet$new(), param_vals = list(),
+    initialize = function(id, param_set = ps(), param_vals = list(),
       packages = character(0), input, output) {
 
       super$initialize(id = id,
