@@ -1,5 +1,15 @@
-weighted_survival_score = function(loss, truth, distribution, times, t_max,
-                                    p_max, proper, train = NULL, eps, ...) {
+score_intslogloss = function(true_times, unique_times, cdf, eps = eps) {
+  assert_number(eps, lower = 0)
+  c_score_intslogloss(true_times, unique_times, cdf, eps = eps)
+}
+
+score_graf_schmid = function(true_times, unique_times, cdf, power = 2) {
+  assert_number(power)
+  c_score_graf_schmid(true_times, unique_times, cdf, power)
+}
+
+
+weighted_survival_score = function(loss, truth, distribution, times, t_max, p_max, proper, train = NULL, eps, ...) {
   assert_surv(truth)
 
   if (is.null(times) || !length(times)) {
@@ -17,22 +27,32 @@ weighted_survival_score = function(loss, truth, distribution, times, t_max,
 
   if (inherits(distribution, "Distribution")) {
     cdf = as.matrix(distribution$cdf(unique_times))
+    if (inherits(distribution, "Matdist")) {
+      cdf = t(cdf) # FIXME - distr6 transposes matdist
+    }
   } else {
-    cdf = 1 - t(distribution[, findInterval(unique_times,
-                                            as.numeric(colnames(distribution)))])
+    mtc = findInterval(unique_times, as.numeric(colnames(distribution)))
+    cdf = 1 - t(distribution[, mtc])
+    if (any(mtc == 0)) {
+      cdf = rbind(matrix(0, sum(mtc == 0), ncol(cdf)), cdf)
+    }
     rownames(cdf) = unique_times
   }
 
   true_times <- truth[, "time"]
 
+  assert_numeric(true_times, any.missing = FALSE)
+  assert_numeric(unique_times, any.missing = FALSE)
+  assert_matrix(cdf, nrows = length(unique_times), ncols = length(true_times), any.missing = FALSE)
+
   ## Note that whilst we calculate the score for censored here, they are then
   ##  corrected in the weighting function
   if (loss == "graf") {
-    score = c_score_graf_schmid(true_times, unique_times, cdf, power = 2)
+    score = score_graf_schmid(true_times, unique_times, cdf, power = 2)
   } else if (loss == "schmid") {
-    score = c_score_graf_schmid(true_times, unique_times, cdf, power = 1)
+    score = score_graf_schmid(true_times, unique_times, cdf, power = 1)
   } else {
-    score = c_score_intslogloss(true_times, unique_times, cdf, eps = eps)
+    score = score_intslogloss(true_times, unique_times, cdf, eps = eps)
   }
 
   if (is.null(train)) {
@@ -41,9 +61,7 @@ weighted_survival_score = function(loss, truth, distribution, times, t_max,
     cens = survival::survfit(Surv(train[, "time"], 1 - train[, "status"]) ~ 1)
   }
 
-  score = .c_weight_survival_score(score, truth, unique_times,
-    matrix(c(cens$time, cens$surv), ncol = 2),
-    proper, eps)
+  score = .c_weight_survival_score(score, truth, unique_times, matrix(c(cens$time, cens$surv), ncol = 2), proper, eps)
   colnames(score) = unique_times
 
   return(score)
@@ -70,8 +88,8 @@ integrated_score = function(score, integrated, method = NULL) {
 
 integrated_se = function(score, integrated) {
   if (integrated) {
-    return(sqrt(sum(stats::cov(score)) / (nrow(score) * ncol(score)^2)))
+    sqrt(sum(stats::cov(score), na.rm = TRUE) / (nrow(score) * ncol(score)^2))
   } else {
-    return(apply(score, 2, function(x) stats::sd(x) / sqrt(nrow(score))))
+    apply(score, 2, function(x) stats::sd(x) / sqrt(nrow(score)))
   }
 }
